# User Guide
```pip3 install django-nest```

```python3 -m django-nest startproject "myproject"```
or
```git clone "https://github.com/Pythonautas/DNest.git" "my_project"```

```cd "my_project"```

start database

```docker-compose up db -d```

start application

```docker-compose up app```